@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-04-22'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2015-04-28'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use strict;
@@ -80,6 +80,12 @@ sub _add_arg {
         $arg_spec->{pos} = $args{pos};
     }
 
+    if ($args{extra_props}) {
+        for (keys %{ $args{extra_props} }) {
+            $arg_spec->{$_} = $args{extra_props}{$_};
+        }
+    }
+
     # translation args
     my %xargs = (field => $fname);
 
@@ -175,6 +181,9 @@ _
         cat_name    => 'field-selection',
         cat_text    => N__('field selection'),
         summary     => N__('Select fields to return'),
+        extra_props => {
+            'x.name.is_plural' => 1,
+        },
     ) if $opts->{enable_field_selection};
     _add_arg(
         func_meta   => $func_meta,
@@ -1472,7 +1481,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.47 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-22.
+This document describes version 0.48 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-28.
 
 =head1 SYNOPSIS
 
